@@ -36,7 +36,6 @@ import pytest
 import statsmodels.api as sm
 # load data into module namespace
 from statsmodels.datasets.cpunish import load
-from statsmodels.discrete import discrete_model as discrete
 from statsmodels.genmod.generalized_linear_model import GLM
 from statsmodels.tools.sm_exceptions import SpecificationWarning
 from statsmodels.tools.tools import add_constant
@@ -53,7 +52,7 @@ cpunish_data.exog[:, 3] = np.log(cpunish_data.exog[:, 3])
 cpunish_data.exog = add_constant(cpunish_data.exog, prepend=False)
 
 
-class CheckWeight(object):
+class CheckWeight:
     def test_basic(self):
         res1 = self.res1
         res2 = self.res2
@@ -98,17 +97,22 @@ class CheckWeight(object):
             return None  # use SkipError instead
         resid_all = dict(zip(res2.resids_colnames, res2.resids.T))
 
-        assert_allclose(res1.resid_response, resid_all['resid_response'], atol= 1e-6, rtol=2e-6)
-        assert_allclose(res1.resid_pearson, resid_all['resid_pearson'], atol= 1e-6, rtol=2e-6)
-        assert_allclose(res1.resid_deviance, resid_all['resid_deviance'], atol= 1e-6, rtol=2e-6)
-        assert_allclose(res1.resid_working, resid_all['resid_working'], atol= 1e-6, rtol=2e-6)
+        assert_allclose(res1.resid_response, resid_all['resid_response'],
+                        atol=1e-6, rtol=2e-6)
+        assert_allclose(res1.resid_pearson, resid_all['resid_pearson'],
+                        atol=1e-6, rtol=2e-6)
+        assert_allclose(res1.resid_deviance, resid_all['resid_deviance'],
+                        atol=1e-6, rtol=2e-6)
+        assert_allclose(res1.resid_working, resid_all['resid_working'],
+                        atol=1e-6, rtol=2e-6)
         if resid_all.get('resid_anscombe') is None:
             return None
         # Stata does not use var_weights in anscombe residuals, it seems.
         # Adjust residuals to match our approach.
         resid_a = res1.resid_anscombe
 
-        assert_allclose(resid_a, resid_all['resid_anscombe'] * np.sqrt(res1._var_weights), atol= 1e-6, rtol=2e-6)
+        resid_a1 = resid_all['resid_anscombe'] * np.sqrt(res1._var_weights)
+        assert_allclose(resid_a, resid_a1, atol=1e-6, rtol=2e-6)
 
     def test_compare_optimizers(self):
         res1 = self.res1
@@ -136,14 +140,17 @@ class CheckWeight(object):
             assert_allclose(self.res1.pearson_chi2, self.res2.deviance_p,
                             atol=1e-6, rtol=1e-6)
 
+    def test_getprediction(self):
+        pred = self.res1.get_prediction()
+        assert_allclose(pred.linpred.se_mean, pred.linpred.se_mean, rtol=1e-10)
+
 
 class TestGlmPoissonPlain(CheckWeight):
     @classmethod
     def setup_class(cls):
         cls.res1 = GLM(cpunish_data.endog, cpunish_data.exog,
                        family=sm.families.Poisson()).fit()
-        # compare with discrete, start close to save time
-        modd = discrete.Poisson(cpunish_data.endog, cpunish_data.exog)
+
         cls.res2 = res_stata.results_poisson_none_nonrobust
 
 
@@ -154,9 +161,9 @@ class TestGlmPoissonFwNr(CheckWeight):
         fweights = np.array(fweights)
 
         cls.res1 = GLM(cpunish_data.endog, cpunish_data.exog,
-                    family=sm.families.Poisson(), freq_weights=fweights).fit()
-        # compare with discrete, start close to save time
-        modd = discrete.Poisson(cpunish_data.endog, cpunish_data.exog)
+                       family=sm.families.Poisson(), freq_weights=fweights
+                       ).fit()
+
         cls.res2 = res_stata.results_poisson_fweight_nonrobust
 
 
@@ -171,9 +178,8 @@ class TestGlmPoissonAwNr(CheckWeight):
         aweights = fweights / wsum * nobs
 
         cls.res1 = GLM(cpunish_data.endog, cpunish_data.exog,
-                    family=sm.families.Poisson(), var_weights=aweights).fit()
-        # compare with discrete, start close to save time
-        modd = discrete.Poisson(cpunish_data.endog, cpunish_data.exog)
+                       family=sm.families.Poisson(), var_weights=aweights
+                       ).fit()
 
         # Need to copy to avoid inplace adjustment
         from copy import copy
@@ -196,9 +202,9 @@ class TestGlmPoissonPwNr(CheckWeight):
         aweights = fweights / wsum * nobs
 
         cls.res1 = GLM(cpunish_data.endog, cpunish_data.exog,
-                    family=sm.families.Poisson(), freq_weights=fweights).fit(cov_type='HC1')
-        # compare with discrete, start close to save time
-        #modd = discrete.Poisson(cpunish_data.endog, cpunish_data.exog)
+                       family=sm.families.Poisson(), freq_weights=fweights
+                       ).fit(cov_type='HC1')
+
         cls.res2 = res_stata.results_poisson_pweight_nonrobust
 
     # TODO: find more informative reasons why these fail
@@ -225,9 +231,9 @@ class TestGlmPoissonFwHC(CheckWeight):
         mod = GLM(cpunish_data.endog, cpunish_data.exog,
                   family=sm.families.Poisson(),
                   freq_weights=fweights)
-        cls.res1 = mod.fit(cov_type='HC0') #, cov_kwds={'use_correction':False})
-        # compare with discrete, start close to save time
-        #modd = discrete.Poisson(cpunish_data.endog, cpunish_data.exog)
+        cls.res1 = mod.fit(cov_type='HC0')
+        # cov_kwds={'use_correction':False})
+
         cls.res2 = res_stata.results_poisson_fweight_hc1
 
 
@@ -250,9 +256,9 @@ class TestGlmPoissonAwHC(CheckWeight):
         mod = GLM(cpunish_data.endog, cpunish_data.exog,
                   family=sm.families.Poisson(),
                   var_weights=aweights)
-        cls.res1 = mod.fit(cov_type='HC0') #, cov_kwds={'use_correction':False})
-        # compare with discrete, start close to save time
-        # modd = discrete.Poisson(cpunish_data.endog, cpunish_data.exog)
+        cls.res1 = mod.fit(cov_type='HC0')
+        # cov_kwds={'use_correction':False})
+
         cls.res2 = res_stata.results_poisson_aweight_hc1
 
 
@@ -270,20 +276,15 @@ class TestGlmPoissonFwClu(CheckWeight):
         n_groups = len(np.unique(gid))
 
         # no wnobs yet in sandwich covariance calcualtion
-        cls.corr_fact = 1 / np.sqrt(n_groups / (n_groups - 1))   #np.sqrt((wsum - 1.) / wsum)
-        cov_kwds = {'groups': gid, 'use_correction':False}
-
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore")
-
-            mod = GLM(
-                cpunish_data.endog, cpunish_data.exog,
-                family=sm.families.Poisson(), freq_weights=fweights
-            )
+        cls.corr_fact = 1 / np.sqrt(n_groups / (n_groups - 1))
+        # np.sqrt((wsum - 1.) / wsum)
+        cov_kwds = {'groups': gid, 'use_correction': False}
+        with pytest.warns(SpecificationWarning):
+            mod = GLM(cpunish_data.endog, cpunish_data.exog,
+                      family=sm.families.Poisson(),
+                      freq_weights=fweights)
             cls.res1 = mod.fit(cov_type='cluster', cov_kwds=cov_kwds)
 
-        # compare with discrete, start close to save time
-        #modd = discrete.Poisson(cpunish_data.endog, cpunish_data.exog)
         cls.res2 = res_stata.results_poisson_fweight_clu1
 
 
@@ -304,7 +305,7 @@ class TestGlmTweedieAwNr(CheckWeight):
                 data=data,
                 family=sm.families.Tweedie(
                     var_power=1.55,
-                    link=sm.families.links.log()
+                    link=sm.families.links.Log()
                     ),
                 var_weights=aweights
         )
@@ -325,7 +326,7 @@ class TestGlmGammaAwNr(CheckWeight):
         aweights[::5] = 5
         aweights[::13] = 3
         model = sm.GLM(endog, exog,
-                       family=sm.families.Gamma(link=sm.families.links.log()),
+                       family=sm.families.Gamma(link=sm.families.links.Log()),
                        var_weights=aweights)
         cls.res1 = model.fit(rtol=1e-25, atol=0)
         cls.res2 = res_r.results_gamma_aweights_nonrobust
@@ -354,7 +355,7 @@ class TestGlmGaussianAwNr(CheckWeight):
         model = smf.glm(
                 'EXECUTIONS ~ INCOME + SOUTH - 1',
                 data=data,
-                family=sm.families.Gaussian(link=sm.families.links.log()),
+                family=sm.families.Gaussian(link=sm.families.links.Log()),
                 var_weights=aweights
         )
         cls.res1 = model.fit(rtol=1e-25, atol=0)
@@ -396,7 +397,8 @@ def gen_endog(lin_pred, family_class, link, binom_version=0):
         else:
             endog = np.empty((len(lin_pred), 2))
             n = 10
-            endog[:, 0] = (np.random.uniform(size=(len(lin_pred), n)) < mu[:, None]).sum(1)
+            endog[:, 0] = (np.random.uniform(size=(len(lin_pred), n)) <
+                           mu[:, None]).sum(1)
             endog[:, 1] = n - endog[:, 0]
     elif family_class == fam.Poisson:
         endog = np.random.poisson(mu)
@@ -430,16 +432,16 @@ def test_wtd_gradient_irls():
 
     fam = sm.families
     lnk = sm.families.links
-    families = [(fam.Binomial, [lnk.logit, lnk.probit, lnk.cloglog, lnk.log,
-                                lnk.cauchy]),
-                (fam.Poisson, [lnk.log, lnk.identity, lnk.sqrt]),
-                (fam.Gamma, [lnk.log, lnk.identity, lnk.inverse_power]),
-                (fam.Gaussian, [lnk.identity, lnk.log, lnk.inverse_power]),
-                (fam.InverseGaussian, [lnk.log, lnk.identity,
-                                       lnk.inverse_power,
-                                       lnk.inverse_squared]),
-                (fam.NegativeBinomial, [lnk.log, lnk.inverse_power,
-                                        lnk.inverse_squared, lnk.identity])]
+    families = [(fam.Binomial, [lnk.Logit, lnk.Probit, lnk.CLogLog, lnk.Log,
+                                lnk.Cauchy]),
+                (fam.Poisson, [lnk.Log, lnk.Identity, lnk.Sqrt]),
+                (fam.Gamma, [lnk.Log, lnk.Identity, lnk.InversePower]),
+                (fam.Gaussian, [lnk.Identity, lnk.Log, lnk.InversePower]),
+                (fam.InverseGaussian, [lnk.Log, lnk.Identity,
+                                       lnk.InversePower,
+                                       lnk.InverseSquared]),
+                (fam.NegativeBinomial, [lnk.Log, lnk.InversePower,
+                                        lnk.InverseSquared, lnk.Identity])]
 
     n = 100
     p = 3
@@ -454,67 +456,67 @@ def test_wtd_gradient_irls():
 
                 if family_class != fam.Binomial and binom_version == 1:
                     continue
-                elif family_class == fam.Binomial and link == lnk.cloglog:
+                elif family_class == fam.Binomial and link == lnk.CLogLog:
                     # Cannot get gradient to converage with var_weights here
                     continue
-                elif family_class == fam.Binomial and link == lnk.log:
+                elif family_class == fam.Binomial and link == lnk.Log:
                     # Cannot get gradient to converage with var_weights here
                     continue
-                elif (family_class, link) == (fam.Poisson, lnk.identity):
+                elif (family_class, link) == (fam.Poisson, lnk.Identity):
                     lin_pred = 20 + exog.sum(1)
-                elif (family_class, link) == (fam.Binomial, lnk.log):
+                elif (family_class, link) == (fam.Binomial, lnk.Log):
                     lin_pred = -1 + exog.sum(1) / 8
-                elif (family_class, link) == (fam.Poisson, lnk.sqrt):
+                elif (family_class, link) == (fam.Poisson, lnk.Sqrt):
                     lin_pred = -2 + exog.sum(1)
-                elif (family_class, link) == (fam.Gamma, lnk.log):
+                elif (family_class, link) == (fam.Gamma, lnk.Log):
                     # Cannot get gradient to converge with var_weights here
                     continue
-                elif (family_class, link) == (fam.Gamma, lnk.identity):
+                elif (family_class, link) == (fam.Gamma, lnk.Identity):
                     # Cannot get gradient to converage with var_weights here
                     continue
-                elif (family_class, link) == (fam.Gamma, lnk.inverse_power):
+                elif (family_class, link) == (fam.Gamma, lnk.InversePower):
                     # Cannot get gradient to converage with var_weights here
                     continue
-                elif (family_class, link) == (fam.Gaussian, lnk.log):
+                elif (family_class, link) == (fam.Gaussian, lnk.Log):
                     # Cannot get gradient to converage with var_weights here
                     continue
-                elif (family_class, link) == (fam.Gaussian, lnk.inverse_power):
+                elif (family_class, link) == (fam.Gaussian, lnk.InversePower):
                     # Cannot get gradient to converage with var_weights here
                     continue
-                elif (family_class, link) == (fam.InverseGaussian, lnk.log):
+                elif (family_class, link) == (fam.InverseGaussian, lnk.Log):
                     # Cannot get gradient to converage with var_weights here
                     lin_pred = -1 + exog.sum(1)
                     continue
                 elif (family_class, link) == (fam.InverseGaussian,
-                                              lnk.identity):
+                                              lnk.Identity):
                     # Cannot get gradient to converage with var_weights here
                     lin_pred = 20 + 5*exog.sum(1)
                     lin_pred = np.clip(lin_pred, 1e-4, np.inf)
                     continue
                 elif (family_class, link) == (fam.InverseGaussian,
-                                              lnk.inverse_squared):
+                                              lnk.InverseSquared):
                     lin_pred = 0.5 + exog.sum(1) / 5
                     continue  # skip due to non-convergence
                 elif (family_class, link) == (fam.InverseGaussian,
-                                              lnk.inverse_power):
+                                              lnk.InversePower):
                     lin_pred = 1 + exog.sum(1) / 5
                     method = 'newton'
                 elif (family_class, link) == (fam.NegativeBinomial,
-                                              lnk.identity):
+                                              lnk.Identity):
                     lin_pred = 20 + 5*exog.sum(1)
                     lin_pred = np.clip(lin_pred, 1e-3, np.inf)
                     method = 'newton'
                 elif (family_class, link) == (fam.NegativeBinomial,
-                                              lnk.inverse_squared):
+                                              lnk.InverseSquared):
                     lin_pred = 0.1 + np.random.uniform(size=exog.shape[0])
                     continue  # skip due to non-convergence
                 elif (family_class, link) == (fam.NegativeBinomial,
-                                              lnk.inverse_power):
+                                              lnk.InversePower):
                     # Cannot get gradient to converage with var_weights here
                     lin_pred = 1 + exog.sum(1) / 5
                     continue
 
-                elif (family_class, link) == (fam.Gaussian, lnk.inverse_power):
+                elif (family_class, link) == (fam.Gaussian, lnk.InversePower):
                     # adding skip because of convergence failure
                     skip_one = True
                 else:
@@ -575,9 +577,9 @@ def test_wtd_gradient_irls():
                                     atol=5e-5)
 
 
-def get_dummies(x, dtype=float):
+def get_dummies(x):
     values = np.sort(np.unique(x))
-    out = np.zeros(shape=(x.shape[0], len(values) - 1), dtype=dtype)
+    out = np.zeros(shape=(x.shape[0], len(values) - 1))
     for i, v in enumerate(values):
         if i == 0:
             continue
@@ -595,11 +597,11 @@ class TestRepeatedvsAggregated(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x, dtype=float)
+        exog[:, 2:] = get_dummies(x)
         beta = np.array([-1, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Poisson
-        link = sm.families.links.log
+        link = sm.families.links.Log
         endog = gen_endog(lin_pred, family, link)
         mod1 = sm.GLM(endog, exog, family=family(link=link()))
         cls.res1 = mod1.fit()
@@ -626,11 +628,11 @@ class TestRepeatedvsAverage(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x, dtype=float)
+        exog[:, 2:] = get_dummies(x)
         beta = np.array([-1, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Poisson
-        link = sm.families.links.log
+        link = sm.families.links.Log
         endog = gen_endog(lin_pred, family, link)
         mod1 = sm.GLM(endog, exog, family=family(link=link()))
         cls.res1 = mod1.fit()
@@ -657,11 +659,11 @@ class TestTweedieRepeatedvsAggregated(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x, dtype=float)
+        exog[:, 2:] = get_dummies(x)
         beta = np.array([7, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Tweedie
-        link = sm.families.links.log
+        link = sm.families.links.Log
         endog = gen_endog(lin_pred, family, link)
         mod1 = sm.GLM(endog, exog, family=family(link=link(), var_power=1.5))
         cls.res1 = mod1.fit(rtol=1e-20, atol=0, tol_criterion='params')
@@ -689,15 +691,15 @@ class TestTweedieRepeatedvsAverage(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x, dtype=float)
+        exog[:, 2:] = get_dummies(x)
         beta = np.array([7, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Tweedie
-        link = sm.families.links.log
+        link = sm.families.links.Log
         endog = gen_endog(lin_pred, family, link)
         mod1 = sm.GLM(endog, exog, family=family(link=link(), var_power=1.5))
         cls.res1 = mod1.fit(rtol=1e-10, atol=0, tol_criterion='params',
-                             scaletype='x2')
+                            scaletype='x2')
 
         agg = pd.DataFrame(exog)
         agg['endog'] = endog
@@ -722,15 +724,15 @@ class TestBinomial0RepeatedvsAverage(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x, dtype=float)
+        exog[:, 2:] = get_dummies(x)
         beta = np.array([-1, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Binomial
-        link = sm.families.links.logit
+        link = sm.families.links.Logit
         endog = gen_endog(lin_pred, family, link, binom_version=0)
         mod1 = sm.GLM(endog, exog, family=family(link=link()))
         cls.res1 = mod1.fit(rtol=1e-10, atol=0, tol_criterion='params',
-                             scaletype='x2')
+                            scaletype='x2')
 
         agg = pd.DataFrame(exog)
         agg['endog'] = endog
@@ -755,11 +757,11 @@ class TestBinomial0RepeatedvsDuplicated(CheckWeight):
         exog[:, 0] = 1
         exog[:, 1] = np.random.randint(low=-5, high=5, size=n)
         x = np.repeat(np.array([1, 2, 3, 4]), n / 4)
-        exog[:, 2:] = get_dummies(x, dtype=float)
+        exog[:, 2:] = get_dummies(x)
         beta = np.array([-1, 0.1, -0.05, .2, 0.35])
         lin_pred = (exog * beta).sum(axis=1)
         family = sm.families.Binomial
-        link = sm.families.links.logit
+        link = sm.families.links.Logit
         endog = gen_endog(lin_pred, family, link, binom_version=0)
         wt = np.random.randint(1, 5, n)
         mod1 = sm.GLM(endog, exog, family=family(link=link()), freq_weights=wt)
@@ -796,7 +798,8 @@ def test_warnings_raised():
 weights = [1, 1, 1, 2, 2, 2, 3, 3, 3, 1, 1, 1, 2, 2, 2, 3, 3]
 
 
-@pytest.mark.parametrize('formatted', [weights, np.asarray(weights), pd.Series(weights)],
+@pytest.mark.parametrize('formatted', [weights, np.asarray(weights),
+                                       pd.Series(weights)],
                          ids=['list', 'ndarray', 'Series'])
 def test_weights_different_formats(formatted):
     check_weights_as_formats(formatted)
@@ -823,18 +826,18 @@ class TestBinomialVsVarWeights(CheckWeight):
     def setup_class(cls):
         from statsmodels.datasets.star98 import load
         data = load()
-        data.exog = np.asarray(data.exog)
-        data.endog = np.asarray(data.endog)
+        data.exog = np.require(data.exog, requirements="W")
+        data.endog = np.require(data.endog, requirements="W")
         data.exog /= data.exog.std(0)
         data.exog = add_constant(data.exog, prepend=False)
 
         cls.res1 = GLM(data.endog, data.exog,
-                        family=sm.families.Binomial()).fit()
+                       family=sm.families.Binomial()).fit()
         weights = data.endog.sum(axis=1)
         endog2 = data.endog[:, 0] / weights
         cls.res2 = GLM(endog2, data.exog,
-                        family=sm.families.Binomial(),
-                        var_weights=weights).fit()
+                       family=sm.families.Binomial(),
+                       var_weights=weights).fit()
 
 
 class TestGlmGaussianWLS(CheckWeight):
@@ -852,7 +855,7 @@ class TestGlmGaussianWLS(CheckWeight):
         model = smf.glm(
                 'EXECUTIONS ~ INCOME + SOUTH - 1',
                 data=data,
-                family=sm.families.Gaussian(link=sm.families.links.identity()),
+                family=sm.families.Gaussian(link=sm.families.links.Identity()),
                 var_weights=aweights
         )
         wlsmodel = smf.wls(
