@@ -361,9 +361,12 @@ class TheilRegressionResults(RegressionResults):
     @cache_readonly
     def aicc(self):
         aic = np.log(self.mse_resid) + 1
-        aic += 2 * (1. + self.hatmatrix_trace()) / (self.nobs - self.hatmatrix_trace() -2)
-        return aic
-
+        eff_dof = self.nobs - self.hatmatrix_trace() - 2
+        if eff_dof > 0:
+            adj = 2 * (1. + self.hatmatrix_trace()) / eff_dof
+        else:
+            adj = np.inf
+        return aic + adj
 
     def test_compatibility(self):
         """Hypothesis test for the compatibility of prior mean with data
@@ -383,7 +386,6 @@ class TheilRegressionResults(RegressionResults):
         # TODO: return results class
         return statistic, pvalue, df
 
-
     def share_data(self):
         """a measure for the fraction of the data in the estimation result
 
@@ -415,6 +417,7 @@ def coef_restriction_meandiff(n_coeffs, n_vars=None, position=0):
         full[:, position:position+n_coeffs] = reduced
         return full
 
+
 def coef_restriction_diffbase(n_coeffs, n_vars=None, position=0, base_idx=0):
 
     reduced = -np.eye(n_coeffs)  #make all rows, drop one row later
@@ -431,9 +434,11 @@ def coef_restriction_diffbase(n_coeffs, n_vars=None, position=0, base_idx=0):
         full[:, position:position+n_coeffs] = reduced
         return full
 
+
 def next_odd(d):
     return d + (1 - d % 2)
 
+
 def coef_restriction_diffseq(n_coeffs, degree=1, n_vars=None, position=0, base_idx=0):
     #check boundaries, returns "valid" ?
 
