@@ -85,6 +85,10 @@ class MarkovAutoregression(markov_regression.MarkovRegression):
     if `trend='c'`, the passed `exog` array should not already have a column of
     ones.
 
+    See the notebook `Markov switching autoregression
+    <../examples/notebooks/generated/markov_autoregression.html>`__
+    for an overview.
+
     References
     ----------
     Kim, Chang-Jin, and Charles R. Nelson. 1999.
