@@ -760,7 +760,7 @@ class SARIMAX(MLEModel):
                 transition[start:end, start:end] = seasonal_companion
 
                 # i
-                for i in range(d + 1, self._k_seasonal_diff):
+                if d < self._k_seasonal_diff - 1:
                     transition[start, end + self.seasonal_periods - 1] = 1
 
                 # \iota
@@ -898,7 +898,7 @@ class SARIMAX(MLEModel):
             params_ma = params[offset:k_params_ma + offset]
             offset += k_params_ma
         if residuals is not None:
-            if len(residuals) > 1:
+            if len(residuals) > max(1, k_params_ma):
                 params_variance = (residuals[k_params_ma:] ** 2).mean()
             else:
                 params_variance = np.var(endog)
@@ -1015,9 +1015,9 @@ class SARIMAX(MLEModel):
         if self.state_regression and self.time_varying_regression:
             # TODO how to set the initial variance parameters?
             params_exog_variance = [1] * self._k_exog
-        if (self.state_error and type(params_variance) == list and
+        if (self.state_error and type(params_variance) is list and
                 len(params_variance) == 0):
-            if not (type(params_seasonal_variance) == list and
+            if not (type(params_seasonal_variance) is list and
                     len(params_seasonal_variance) == 0):
                 params_variance = params_seasonal_variance
             elif self._k_exog > 0:
