@@ -5,10 +5,10 @@ from __future__ import annotations
 
 from statsmodels.compat.numpy import lstsq
 from statsmodels.compat.pandas import deprecate_kwarg
-from statsmodels.compat.python import lzip, Literal
+from statsmodels.compat.python import Literal, lzip
 from statsmodels.compat.scipy import _next_regular
 
-from typing import Tuple
+from typing import Union, List
 import warnings
 
 import numpy as np
@@ -24,6 +24,7 @@ from statsmodels.tools.sm_exceptions import (
     InfeasibleTestError,
     InterpolationWarning,
     MissingDataError,
+    ValueWarning,
 )
 from statsmodels.tools.tools import Bunch, add_constant
 from statsmodels.tools.validation import (
@@ -37,7 +38,9 @@ from statsmodels.tools.validation import (
 from statsmodels.tsa._bds import bds
 from statsmodels.tsa._innovations import innovations_algo, innovations_filter
 from statsmodels.tsa.adfvalues import mackinnoncrit, mackinnonp
-from statsmodels.tsa.tsatools import add_trend, lagmat, lagmat2ds, rename_trend
+from statsmodels.tsa.tsatools import add_trend, lagmat, lagmat2ds
+
+ArrayLike1D = Union[np.ndarray, pd.Series, List[float]]
 
 __all__ = [
     "acovf",
@@ -239,6 +242,10 @@ def adfuller(
 
     The autolag option and maxlag for it are described in Greene.
 
+    See the notebook `Stationarity and detrending (ADF/KPSS)
+    <../examples/notebooks/generated/stationarity_detrending_adf_kpss.html>`__
+    for an overview.
+
     References
     ----------
     .. [1] W. Green.  "Econometric Analysis," 5th ed., Pearson, 2003.
@@ -252,14 +259,9 @@ def adfuller(
     .. [4] MacKinnon, J.G. 2010. "Critical Values for Cointegration Tests."  Queen"s
         University, Dept of Economics, Working Papers.  Available at
         http://ideas.repec.org/p/qed/wpaper/1227.html
-
-    Examples
-    --------
-    See example notebook
     """
     x = array_like(x, "x")
     maxlag = int_like(maxlag, "maxlag", optional=True)
-    regression = rename_trend(regression)
     regression = string_like(
         regression, "regression", options=("c", "ct", "ctt", "n")
     )
@@ -269,6 +271,9 @@ def adfuller(
     store = bool_like(store, "store")
     regresults = bool_like(regresults, "regresults")
 
+    if x.max() == x.min():
+        raise ValueError("Invalid input, x is constant")
+
     if regresults:
         store = True
 
@@ -545,6 +550,13 @@ def q_stat(x, nobs):
     p-value : ndarray
         P-value of the Q statistic.
 
+    See Also
+    --------
+    statsmodels.stats.diagnostic.acorr_ljungbox
+        Ljung-Box Q-test for autocorrelation in time series based
+        on a time series rather than the estimated autocorrelation
+        function.
+
     Notes
     -----
     Designed to be used with acf.
@@ -681,27 +693,29 @@ def acf(
     acf = avf[: nlags + 1] / avf[0]
     if not (qstat or alpha):
         return acf
+    _alpha = alpha if alpha is not None else 0.05
+    if bartlett_confint:
+        varacf = np.ones_like(acf) / nobs
+        varacf[0] = 0
+        varacf[1] = 1.0 / nobs
+        varacf[2:] *= 1 + 2 * np.cumsum(acf[1:-1] ** 2)
+    else:
+        varacf = 1.0 / len(x)
+    interval = stats.norm.ppf(1 - _alpha / 2.0) * np.sqrt(varacf)
+    confint = np.array(lzip(acf - interval, acf + interval))
+    if not qstat:
+        return acf, confint
+    qstat, pvalue = q_stat(acf[1:], nobs=nobs)  # drop lag 0
     if alpha is not None:
-        if bartlett_confint:
-            varacf = np.ones_like(acf) / nobs
-            varacf[0] = 0
-            varacf[1] = 1.0 / nobs
-            varacf[2:] *= 1 + 2 * np.cumsum(acf[1:-1] ** 2)
-        else:
-            varacf = 1.0 / len(x)
-        interval = stats.norm.ppf(1 - alpha / 2.0) * np.sqrt(varacf)
-        confint = np.array(lzip(acf - interval, acf + interval))
-        if not qstat:
-            return acf, confint
-    if qstat:
-        qstat, pvalue = q_stat(acf[1:], nobs=nobs)  # drop lag 0
-        if alpha is not None:
-            return acf, confint, qstat, pvalue
-        else:
-            return acf, qstat, pvalue
+        return acf, confint, qstat, pvalue
+    else:
+        return acf, qstat, pvalue
 
-
-def pacf_yw(x, nlags=None, method="adjusted"):
+def pacf_yw(
+    x: ArrayLike1D,
+    nlags: int | None = None,
+    method: Literal["adjusted", "mle"] = "adjusted",
+) -> np.ndarray:
     """
     Partial autocorrelation estimated with non-recursive yule_walker.
 
@@ -738,16 +752,19 @@ def pacf_yw(x, nlags=None, method="adjusted"):
     nlags = int_like(nlags, "nlags", optional=True)
     nobs = x.shape[0]
     if nlags is None:
-        nlags = min(int(10 * np.log10(nobs)), nobs - 1)
-
+        nlags = max(min(int(10 * np.log10(nobs)), nobs - 1), 1)
     method = string_like(method, "method", options=("adjusted", "mle"))
     pacf = [1.0]
-    for k in range(1, nlags + 1):
-        pacf.append(yule_walker(x, k, method=method)[0][-1])
+    with warnings.catch_warnings():
+        warnings.simplefilter("once", ValueWarning)
+        for k in range(1, nlags + 1):
+            pacf.append(yule_walker(x, k, method=method)[0][-1])
     return np.array(pacf)
 
 
-def pacf_burg(x, nlags=None, demean=True):
+def pacf_burg(
+    x: ArrayLike1D, nlags: int | None = None, demean: bool = True
+) -> tuple[np.ndarray, np.ndarray]:
     """
     Calculate Burg"s partial autocorrelation estimator.
 
@@ -789,6 +806,7 @@ def pacf_burg(x, nlags=None, demean=True):
         x = x - x.mean()
     nobs = x.shape[0]
     p = nlags if nlags is not None else min(int(10 * np.log10(nobs)), nobs - 1)
+    p = max(p, 1)
     if p > nobs - 1:
         raise ValueError("nlags must be smaller than nobs - 1")
     d = np.zeros(p + 1)
@@ -807,14 +825,19 @@ def pacf_burg(x, nlags=None, demean=True):
         v[1:] = last_v[1:] - pacf[i] * last_u[:-1]
         d[i + 1] = (1 - pacf[i] ** 2) * d[i] - v[i] ** 2 - u[-1] ** 2
         pacf[i + 1] = 2 / d[i + 1] * v[i + 1 :].dot(u[i:-1])
-    sigma2 = (1 - pacf ** 2) * d / (2.0 * (nobs - np.arange(0, p + 1)))
+    sigma2 = (1 - pacf**2) * d / (2.0 * (nobs - np.arange(0, p + 1)))
     pacf[0] = 1  # Insert the 0 lag partial autocorrel
 
     return pacf, sigma2
 
 
 @deprecate_kwarg("unbiased", "adjusted")
-def pacf_ols(x, nlags=None, efficient=True, adjusted=False):
+def pacf_ols(
+    x: ArrayLike1D,
+    nlags: int | None = None,
+    efficient: bool = True,
+    adjusted: bool = False,
+) -> np.ndarray:
     """
     Calculate partial autocorrelations via OLS.
 
@@ -874,8 +897,9 @@ def pacf_ols(x, nlags=None, efficient=True, adjusted=False):
     adjusted = bool_like(adjusted, "adjusted")
     nobs = x.shape[0]
     if nlags is None:
-        nlags = min(int(10 * np.log10(nobs)), nobs - 1)
-
+        nlags = max(min(int(10 * np.log10(nobs)), nobs // 2), 1)
+    if nlags > nobs//2:
+        raise ValueError(f"nlags must be smaller than nobs // 2 ({nobs//2})")
     pacf = np.empty(nlags + 1)
     pacf[0] = 1.0
     if efficient:
@@ -883,7 +907,7 @@ def pacf_ols(x, nlags=None, efficient=True, adjusted=False):
         xlags = add_constant(xlags)
         for k in range(1, nlags + 1):
             params = lstsq(xlags[k:, : k + 1], x0[k:], rcond=None)[0]
-            pacf[k] = params[-1]
+            pacf[k] = np.squeeze(params[-1])
     else:
         x = x - np.mean(x)
         # Create a single set of lags for multivariate OLS
@@ -891,15 +915,31 @@ def pacf_ols(x, nlags=None, efficient=True, adjusted=False):
         for k in range(1, nlags + 1):
             params = lstsq(xlags[:, :k], x0, rcond=None)[0]
             # Last coefficient corresponds to PACF value (see [1])
-            pacf[k] = params[-1]
-
+            pacf[k] = np.squeeze(params[-1])
     if adjusted:
         pacf *= nobs / (nobs - np.arange(nlags + 1))
-
     return pacf
 
 
-def pacf(x, nlags=None, method="ywadjusted", alpha=None):
+def pacf(
+    x: ArrayLike1D,
+    nlags: int | None = None,
+    method: Literal[
+        "yw",
+        "ywadjusted",
+        "ols",
+        "ols-inefficient",
+        "ols-adjusted",
+        "ywm",
+        "ywmle",
+        "ld",
+        "ldadjusted",
+        "ldb",
+        "ldbiased",
+        "burg",
+    ] = "ywadjusted",
+    alpha: float | None = None,
+) -> np.ndarray | tuple[np.ndarray, np.ndarray]:
     """
     Partial autocorrelation estimate.
 
@@ -926,6 +966,7 @@ def pacf(x, nlags=None, method="ywadjusted", alpha=None):
           correction.
         - "ldb" or "ldbiased" : Levinson-Durbin recursion without bias
           correction.
+        - "burg" :  Burg"s partial autocorrelation estimator.
 
     alpha : float, optional
         If a number is given, the confidence intervals for the given level are
@@ -984,6 +1025,7 @@ def pacf(x, nlags=None, method="ywadjusted", alpha=None):
         "ldb",
         "ldbiased",
         "ld_biased",
+        "burg",
     )
     x = array_like(x, "x", maxdim=2)
     method = string_like(method, "method", options=methods)
@@ -992,13 +1034,13 @@ def pacf(x, nlags=None, method="ywadjusted", alpha=None):
     nobs = x.shape[0]
     if nlags is None:
         nlags = min(int(10 * np.log10(nobs)), nobs // 2 - 1)
-    if nlags >= x.shape[0] // 2:
+    nlags = max(nlags, 1)
+    if nlags > x.shape[0] // 2:
         raise ValueError(
             "Can only compute partial correlations for lags up to 50% of the "
             f"sample size. The requested nlags {nlags} must be < "
             f"{x.shape[0] // 2}."
         )
-
     if method in ("ols", "ols-inefficient", "ols-adjusted"):
         efficient = "inefficient" not in method
         adjusted = "adjusted" in method
@@ -1011,12 +1053,13 @@ def pacf(x, nlags=None, method="ywadjusted", alpha=None):
         acv = acovf(x, adjusted=True, fft=False)
         ld_ = levinson_durbin(acv, nlags=nlags, isacov=True)
         ret = ld_[2]
+    elif method == "burg":
+        ret, _ = pacf_burg(x, nlags=nlags, demean=True)
     # inconsistent naming with ywmle
     else:  # method in ("ldb", "ldbiased", "ld_biased")
         acv = acovf(x, adjusted=False, fft=False)
         ld_ = levinson_durbin(acv, nlags=nlags, isacov=True)
         ret = ld_[2]
-
     if alpha is not None:
         varacf = 1.0 / len(x)  # for all lags >=1
         interval = stats.norm.ppf(1.0 - alpha / 2.0) * np.sqrt(varacf)
@@ -1030,14 +1073,14 @@ def pacf(x, nlags=None, method="ywadjusted", alpha=None):
 @deprecate_kwarg("unbiased", "adjusted")
 def ccovf(x, y, adjusted=True, demean=True, fft=True):
     """
-    Calculate the crosscovariance between two series.
+    Calculate the cross-covariance between two series.
 
     Parameters
     ----------
     x, y : array_like
        The time series data to use in the calculation.
     adjusted : bool, optional
-       If True, then denominators for crosscovariance is n-k, otherwise n.
+       If True, then denominators for cross-covariance are n-k, otherwise n.
     demean : bool, optional
         Flag indicating whether to demean x and y.
     fft : bool, default True
@@ -1047,7 +1090,9 @@ def ccovf(x, y, adjusted=True, demean=True, fft=True):
     Returns
     -------
     ndarray
-        The estimated crosscovariance function.
+        The estimated cross-covariance function: the element at index k
+        is the covariance between {x[k], x[k+1], ..., x[n]} and {y[0], y[1], ..., y[m-k]},
+        where n and m are the lengths of x and y, respectively.
     """
     x = array_like(x, "x")
     y = array_like(y, "y")
@@ -1068,11 +1113,11 @@ def ccovf(x, y, adjusted=True, demean=True, fft=True):
         d = n
 
     method = "fft" if fft else "direct"
-    return correlate(xo, yo, "full", method=method)[n - 1 :] / d
+    return correlate(xo, yo, "full", method=method)[n - 1:] / d
 
 
 @deprecate_kwarg("unbiased", "adjusted")
-def ccf(x, y, adjusted=True, fft=True):
+def ccf(x, y, adjusted=True, fft=True, *, nlags=None, alpha=None):
     """
     The cross-correlation function.
 
@@ -1081,19 +1126,38 @@ def ccf(x, y, adjusted=True, fft=True):
     x, y : array_like
         The time series data to use in the calculation.
     adjusted : bool
-        If True, then denominators for cross-correlation is n-k, otherwise n.
+        If True, then denominators for cross-correlation are n-k, otherwise n.
     fft : bool, default True
         If True, use FFT convolution.  This method should be preferred
         for long time series.
+    nlags : int, optional
+        Number of lags to return cross-correlations for. If not provided,
+        the number of lags equals len(x).
+    alpha : float, optional
+        If a number is given, the confidence intervals for the given level are
+        returned. For instance if alpha=.05, 95 % confidence intervals are
+        returned where the standard deviation is computed according to
+        1/sqrt(len(x)).
 
     Returns
     -------
     ndarray
-        The cross-correlation function of x and y.
+        The cross-correlation function of x and y: the element at index k
+        is the correlation between {x[k], x[k+1], ..., x[n]} and {y[0], y[1], ..., y[m-k]},
+        where n and m are the lengths of x and y, respectively.
+    confint : ndarray, optional
+        Confidence intervals for the CCF at lags 0, 1, ..., nlags-1 using the level given by
+        alpha and the standard deviation calculated as 1/sqrt(len(x)) [1]. Shape (nlags, 2).
+        Returned if alpha is not None.
 
     Notes
     -----
-    If adjusted is true, the denominator for the autocovariance is adjusted.
+    If adjusted is True, the denominator for the cross-correlation is adjusted.
+
+    References
+    ----------
+    .. [1] Brockwell and Davis, 2016. Introduction to Time Series and
+       Forecasting, 3rd edition, p. 242.
     """
     x = array_like(x, "x")
     y = array_like(y, "y")
@@ -1101,7 +1165,15 @@ def ccf(x, y, adjusted=True, fft=True):
     fft = bool_like(fft, "fft", optional=False)
 
     cvf = ccovf(x, y, adjusted=adjusted, demean=True, fft=fft)
-    return cvf / (np.std(x) * np.std(y))
+    ret = cvf / (np.std(x) * np.std(y))
+    ret = ret[:nlags]
+
+    if alpha is not None:
+        interval = stats.norm.ppf(1.0 - alpha / 2.0) / np.sqrt(len(x))
+        confint = ret.reshape(-1, 1) + interval * np.array([-1, 1])
+        return ret, confint
+    else:
+        return ret
 
 
 # moved from sandbox.tsa.examples.try_ld_nitime, via nitime
@@ -1327,7 +1399,8 @@ def breakvar_heteroskedasticity_test(
             warnings.warn(
                 "Early subset of data for variable %d"
                 " has too few non-missing observations to"
-                " calculate test statistic." % i
+                " calculate test statistic." % i,
+                stacklevel=2,
             )
             numer_squared_sum[i] = np.nan
 
@@ -1339,7 +1412,8 @@ def breakvar_heteroskedasticity_test(
             warnings.warn(
                 "Later subset of data for variable %d"
                 " has too few non-missing observations to"
-                " calculate test statistic." % i
+                " calculate test statistic." % i,
+                stacklevel=2,
             )
             denom_squared_sum[i] = np.nan
 
@@ -1385,7 +1459,7 @@ def breakvar_heteroskedasticity_test(
     return test_statistic, p_value
 
 
-def grangercausalitytests(x, maxlag, addconst=True, verbose=True):
+def grangercausalitytests(x, maxlag, addconst=True, verbose=None):
     """
     Four tests for granger non causality of 2 time series.
 
@@ -1404,7 +1478,13 @@ def grangercausalitytests(x, maxlag, addconst=True, verbose=True):
     addconst : bool
         Include a constant in the model.
     verbose : bool
-        Print results.
+        Print results. Deprecated
+
+        .. deprecated: 0.14
+
+           verbose is deprecated and will be removed after 0.15 is released
+
+
 
     Returns
     -------
@@ -1449,20 +1529,30 @@ def grangercausalitytests(x, maxlag, addconst=True, verbose=True):
     >>> data = data.data[["realgdp", "realcons"]].pct_change().dropna()
 
     All lags up to 4
+
     >>> gc_res = grangercausalitytests(data, 4)
 
     Only lag 4
+
     >>> gc_res = grangercausalitytests(data, [4])
     """
     x = array_like(x, "x", ndim=2)
     if not np.isfinite(x).all():
         raise ValueError("x contains NaN or inf values.")
     addconst = bool_like(addconst, "addconst")
-    verbose = bool_like(verbose, "verbose")
+    if verbose is not None:
+        verbose = bool_like(verbose, "verbose")
+        warnings.warn(
+            "verbose is deprecated since functions should not print results",
+            FutureWarning,
+        )
+    else:
+        verbose = True  # old default
+
     try:
         maxlag = int_like(maxlag, "maxlag")
         if maxlag <= 0:
-            raise ValueError("maxlag must a a positive integer")
+            raise ValueError("maxlag must be a positive integer")
         lags = np.arange(1, maxlag + 1)
     except TypeError:
         lags = np.array([int(lag) for lag in maxlag])
@@ -1476,7 +1566,7 @@ def grangercausalitytests(x, maxlag, addconst=True, verbose=True):
     if x.shape[0] <= 3 * maxlag + int(addconst):
         raise ValueError(
             "Insufficient observations. Maximum allowable "
-            "lag is {0}".format(int((x.shape[0] - int(addconst)) / 3) - 1)
+            "lag is {}".format(int((x.shape[0] - int(addconst)) / 3) - 1)
         )
 
     resli = {}
@@ -1694,7 +1784,6 @@ def coint(
     """
     y0 = array_like(y0, "y0")
     y1 = array_like(y1, "y1", ndim=2)
-    trend = rename_trend(trend)
     trend = string_like(trend, "trend", options=("c", "n", "ct", "ctt"))
     string_like(method, "method", options=("aeg",))
     maxlag = int_like(maxlag, "maxlag", optional=True)
@@ -1722,6 +1811,7 @@ def coint(
             "y0 and y1 are (almost) perfectly colinear."
             "Cointegration test is not reliable in this case.",
             CollinearityWarning,
+            stacklevel=2,
         )
         # Edge case where series are too similar
         res_adf = (-np.inf,)
@@ -1862,8 +1952,10 @@ def arma_order_select_ic(
     # add the minimums to the results dict
     min_res = {}
     for i, result in res.items():
-        mins = np.where(result.min().min() == result)
-        min_res.update({i + "_min_order": (mins[0][0], mins[1][0])})
+        delta = np.ascontiguousarray(np.abs(result.min().min() - result))
+        ncols = delta.shape[1]
+        loc = np.argmin(delta)
+        min_res.update({i + "_min_order": (loc // ncols, loc % ncols)})
     res.update(min_res)
 
     return Bunch(**res)
@@ -1881,7 +1973,7 @@ def kpss(
     regression: Literal["c", "ct"] = "c",
     nlags: Literal["auto", "legacy"] | int = "auto",
     store: bool = False,
-) -> Tuple[float, float, int, dict[str, float]]:
+) -> tuple[float, float, int, dict[str, float]]:
     """
     Kwiatkowski-Phillips-Schmidt-Shin test for stationarity.
 
@@ -1936,6 +2028,10 @@ def kpss(
 
     Missing values are not handled.
 
+    See the notebook `Stationarity and detrending (ADF/KPSS)
+    <../examples/notebooks/generated/stationarity_detrending_adf_kpss.html>`__
+    for an overview.
+
     References
     ----------
     .. [1] Andrews, D.W.K. (1991). Heteroskedasticity and autocorrelation
@@ -1964,7 +2060,7 @@ def kpss(
 
     # if m is not one, n != m * n
     if nobs != x.size:
-        raise ValueError("x of shape {0} not understood".format(x.shape))
+        raise ValueError(f"x of shape {x.shape} not understood")
 
     if hypo == "ct":
         # p. 162 Kwiatkowski et al. (1992): y_t = beta * t + r_t + e_t,
@@ -1988,6 +2084,7 @@ def kpss(
                 "None is not a valid value for nlags. It must be an integer, "
                 "'auto' or 'legacy'. None will raise starting in 0.14",
                 FutureWarning,
+                stacklevel=2,
             )
         # autolag method of Hobijn et al. (1998)
         nlags = _kpss_autolag(resids, nobs)
@@ -2016,11 +2113,15 @@ look-up table. The actual p-value is {direction} than the p-value returned.
 """
     if p_value == pvals[-1]:
         warnings.warn(
-            warn_msg.format(direction="smaller"), InterpolationWarning
+            warn_msg.format(direction="smaller"),
+            InterpolationWarning,
+            stacklevel=2,
         )
     elif p_value == pvals[0]:
         warnings.warn(
-            warn_msg.format(direction="greater"), InterpolationWarning
+            warn_msg.format(direction="greater"),
+            InterpolationWarning,
+            stacklevel=2,
         )
 
     crit_dict = {"10%": crit[0], "5%": crit[1], "2.5%": crit[2], "1%": crit[3]}
@@ -2033,8 +2134,8 @@ look-up table. The actual p-value is {direction} than the p-value returned.
         rstore.nobs = nobs
 
         stationary_type = "level" if hypo == "c" else "trend"
-        rstore.H0 = "The series is {0} stationary".format(stationary_type)
-        rstore.HA = "The series is not {0} stationary".format(stationary_type)
+        rstore.H0 = f"The series is {stationary_type} stationary"
+        rstore.HA = f"The series is not {stationary_type} stationary"
 
         return kpss_stat, p_value, crit_dict, rstore
     else:
@@ -2127,7 +2228,7 @@ def range_unit_root_test(x, store=False):
 
     # if m is not one, n != m * n
     if nobs != x.size:
-        raise ValueError("x of shape {0} not understood".format(x.shape))
+        raise ValueError(f"x of shape {x.shape} not understood")
 
     # Table from [1] has been replicated using 200,000 samples
     # Critical values for new n_obs values have been identified
@@ -2187,7 +2288,9 @@ look-up table. The actual p-value is {direction} than the p-value returned.
 
     if direction:
         warnings.warn(
-            warn_msg.format(direction=direction), InterpolationWarning
+            warn_msg.format(direction=direction),
+            InterpolationWarning,
+            stacklevel=2,
         )
 
     crit_dict = {
@@ -2211,7 +2314,7 @@ look-up table. The actual p-value is {direction} than the p-value returned.
         return rur_stat, p_value, crit_dict
 
 
-class ZivotAndrewsUnitRoot(object):
+class ZivotAndrewsUnitRoot:
     """
     Class wrapper for Zivot-Andrews structural-break unit-root test
     """
