@@ -80,7 +80,7 @@ def sublists(lst, min_elmts=0, max_elmts=None):
     result = itertools.chain.from_iterable(
                 itertools.combinations(lst, sublist_len)
                 for sublist_len in range(min_elmts, max_elmts+1))
-    if type(result) != list:
+    if type(result) is not list:
         result = list(result)
     return result
 
@@ -183,7 +183,7 @@ def load_results_jmulti(dataset):
         # ---------------------------------------------------------------------
         # parse information about \alpha, \beta, \Gamma, deterministic of VECM
         # and A_i and deterministic of corresponding VAR:
-        params_file = open(params_file)
+        params_file = open(params_file, encoding="latin_1")
         for line in params_file:
             if section == -1 and section_header[section+1] not in line:
                 continue
@@ -280,7 +280,7 @@ def load_results_jmulti(dataset):
         # all numbers of Sigma_u in notation with e (e.g. 2.283862e-05)
         regex_est = re.compile(r"\s+\S+e\S+")
         sigmau_section_reached = False
-        sigmau_file = open(sigmau_file)
+        sigmau_file = open(sigmau_file, encoding="latin_1")
         for line in sigmau_file:
             if line.startswith("Log Likelihood:"):
                 line = line.split("Log Likelihood:")[1]
@@ -344,7 +344,7 @@ def load_results_jmulti(dataset):
                 + stringify_var_names(causing) + "_" \
                 + stringify_var_names(caused) + ".txt"
             granger_file = os.path.join(here, granger_file)
-            granger_file = open(granger_file)
+            granger_file = open(granger_file, encoding="latin_1")
             granger_results = []
             for line in granger_file:
                 str_number = r"\d+\.\d{4}"
@@ -383,7 +383,7 @@ def load_results_jmulti(dataset):
                 + stringify_var_names(causing) + "_" \
                 + stringify_var_names(caused) + ".txt"
             inst_file = os.path.join(here, inst_file)
-            inst_file = open(inst_file)
+            inst_file = open(inst_file, encoding="latin_1")
             inst_results = []
             for line in inst_file:
                 str_number = r"\d+\.\d{4}"
